@@ -485,8 +485,8 @@ class PdbxLoader(object):
         self.__maxStepLength = maxStepLength
         #
         # Controls for multiprocessing execution -
-        self.__numProc = numProc
-        self.__chunkSize = chunkSize
+        self.__numProc = max(numProc, 1)
+        self.__chunkSize = max(chunkSize, 1)
         #
         self.__cfgOb = cfgOb
         self.__resourceName = resourceName
@@ -521,6 +521,7 @@ class PdbxLoader(object):
         validationLevel="min",
         mergeContentTypes=None,
         useNameFlag=True,
+        updateSchemaOnReplace=False,
     ):
         """Driver method for loading PDBx/mmCIF content into the Mongo document store.
 
@@ -537,6 +538,7 @@ class PdbxLoader(object):
             logSize (bool, optional): Compute and log bson serialized object size
             validationLevel (str, optional): Completeness of json/bson metadata schema bound to each collection (e.g. 'min', 'full' or None)
             useNameFlag (bool, optional): Use container name as unique identifier otherwise use UID property.
+            updateSchemaOnReplace (bool, optional): Update validation schema for loadType == 'replace'
         Returns:
             bool: True on success or False otherwise
 
@@ -547,16 +549,23 @@ class PdbxLoader(object):
             desp = DataExchangeStatus()
             statusStartTimestamp = desp.setStartTime()
             #
+            logger.info("Beginning load operation (%r) for database %s", loadType, databaseName)
             startTime = self.__begin(message="loading operation")
             #
             modulePathMap = self.__cfgOb.get("DICT_METHOD_HELPER_MODULE_PATH_MAP", sectionName=self.__sectionName)
             dP = DictionaryApiProviderWrapper(self.__cfgOb, self.__cachePath, useCache=True)
             dictApi = dP.getApiByName(databaseName)
+            # ---
             dmrP = DictMethodResourceProvider(self.__cfgOb, cachePath=self.__cachePath)
+            # Cache dependencies in serial mode.
+            ok = dmrP.cacheResources(useCache=True)
+            if not ok:
+                logger.error("Checking cached resource dependencies failed - %s load (%r) aborted", databaseName, loadType)
+                return ok
+            # ---
             self.__dmh = DictMethodRunner(dictApi, modulePathMap=modulePathMap, resourceProvider=dmrP)
-
             locatorObjList = self.__rpP.getLocatorObjList(contentType=databaseName, inputPathList=inputPathList, mergeContentTypes=mergeContentTypes)
-            logger.debug("Path list length %d", len(locatorObjList))
+            logger.info("Loading database %s (%r) with path length %d", databaseName, loadType, len(locatorObjList))
             #
             if saveInputFileListPath:
                 self.__writePathList(saveInputFileListPath, self.__rpP.getLocatorPaths(locatorObjList))
@@ -595,6 +604,14 @@ class PdbxLoader(object):
                         bsonSchema = self.__schP.getJsonSchema(databaseName, collectionName, encodingType="BSON", level=validationLevel)
                     ok = self.__createCollection(databaseName, collectionName, indexDL=indexDL, bsonSchema=bsonSchema)
                     logger.debug("Collection create return status %r", ok)
+                elif loadType == "replace" and updateSchemaOnReplace:
+                    bsonSchema = None
+                    if validationLevel and validationLevel in ["min", "full"]:
+                        bsonSchema = self.__schP.getJsonSchema(databaseName, collectionName, encodingType="BSON", level=validationLevel)
+                    if bsonSchema:
+                        ok = self.__updateCollectionSchema(databaseName, collectionName, bsonSchema=bsonSchema)
+                        if not ok:
+                            logger.info("Schema update failing for %s (%s)", databaseName, collectionName)
             #
             dtf = DataTransformFactory(schemaDefAccessObj=sd, filterType=filterType)
             optD["schemaDefAccess"] = sd
@@ -613,7 +630,9 @@ class PdbxLoader(object):
                 subLists = [locatorObjList]
             #
             if subLists:
-                logger.info("Starting loadType %s with numProc %d outer subtask count %d subtask length %d", loadType, numProc, len(subLists), len(subLists[0]))
+                logger.info("Starting load of %s (%r) using numProc %d outer subtask count %d subtask length %d", databaseName, loadType, numProc, len(subLists), len(subLists[0]))
+            else:
+                logger.error("Path partitioning fails for %s (%r) using numProc %d", databaseName, loadType, numProc)
             #
             failList = []
             for ii, subList in enumerate(subLists):
@@ -649,9 +668,16 @@ class PdbxLoader(object):
                 self.__statusList.append(desp.getStatus())
             #
             if ok:
-                logger.info("Load operation returning status %r loading %d paths", ok, numPaths)
+                logger.info("Completed loading %s with status %r loaded %d paths", databaseName, ok, numPaths)
             else:
-                logger.info("Load operation returns status %r failure count %d of %d paths: %r", ok, len(failList), numPaths, [os.path.basename(pth) for pth in failedPathList])
+                logger.info(
+                    "Completed loading %s with status %r failure count %d of %d paths: %r",
+                    databaseName,
+                    ok,
+                    len(failList),
+                    numPaths,
+                    [os.path.basename(pth) for pth in failedPathList],
+                )
             #
             return ok
         except Exception as e:
@@ -873,6 +899,24 @@ class PdbxLoader(object):
             logger.exception("Failing with %s", str(e))
         return False
 
+    def __updateCollectionSchema(self, databaseName, collectionName, bsonSchema=None, validationLevel="strict", validationAction="error"):
+        """Update validation schema for the input collection -
+        """
+        try:
+            logger.debug("Updating validatio for schema database %s collection %s", databaseName, collectionName)
+            with Connection(cfgOb=self.__cfgOb, resourceName=self.__resourceName) as client:
+                mg = MongoDbUtil(client)
+                ok1 = mg.databaseExists(databaseName)
+                ok2 = mg.collectionExists(databaseName, collectionName)
+                if ok1 and ok2:
+                    ok3 = mg.updateCollection(databaseName, collectionName, bsonSchema=bsonSchema, validationLevel=validationLevel, validationAction=validationAction)
+                    logger.info("Updated %r %r validation schema", databaseName, collectionName)
+            return ok1 and ok2 and ok3
+            #
+        except Exception as e:
+            logger.exception("Failing with %s", str(e))
+        return False
+
     def __removeCollection(self, databaseName, collectionName):
         """Drop collection within database
 
